@@ -1,6 +1,6 @@
 package Mojo::Webqq;
 use strict;
-$Mojo::Webqq::VERSION = "1.6.8";
+$Mojo::Webqq::VERSION = "1.6.9";
 use base qw(Mojo::Base);
 use Mojo::Webqq::Log;
 use Mojo::Webqq::Cache;
@@ -71,6 +71,7 @@ has sess_sig_cache => sub {Mojo::Webqq::Cache->new};
 has id_to_qq_cache => sub {Mojo::Webqq::Cache->new};
 
 has is_stop                 => 0;
+has is_ready                => 0;
 has ua_retry_times          => 5;
 has is_first_login          => -1;
 has login_state             => "init";#init|relogin|success|scaning|confirming
@@ -80,8 +81,8 @@ has poll_failure_count      => 0;
 has poll_failure_count_max  => 3;
 has message_queue           => sub { $_[0]->gen_message_queue };
 has ua                      => sub {
-    local $ENV{MOJO_USERAGENT_DEBUG} = $_[0]->ua_debug;
     require Mojo::UserAgent;
+    #local $ENV{MOJO_USERAGENT_DEBUG} = $_[0]->ua_debug; 
     require Storable if $_[0]->keep_cookie;
     Mojo::UserAgent->new(
         max_redirects      => 7,
@@ -138,7 +139,7 @@ sub on {
 sub new {
     my $class = shift;
     my $self  = $class->SUPER::new(@_);
-    $ENV{MOJO_USERAGENT_DEBUG} = $self->{ua_debug};
+    #$ENV{MOJO_USERAGENT_DEBUG} = $self->{ua_debug};
     if(not defined $self->{qq}){
         $self->fatal("客户端初始化缺少qq参数");
         $self->exit();
